s6: the s6-fdholder-transferdump program
Keywords: s6 s6-fdholder fd-holding fd-holder fd dump transfer unix socket activation

s6
Software
skarnet.org

# The `s6-fdholder-transferdump` program

`s6-fdholder-transferdump` connects to two separate fd-holding daemons and transfers the content of the first one to the second one.

## Interface

         s6-fdholder-transferdump [ -t timeoutfrom:timeoutto ] pathfrom pathto

- s6-fdholder-transferdump executes into a more complex command line involving two s6-ipcclient invocations and ending with s6-fdholder-transferdumpc. It is just a convenience program: the real transfer is performed by s6-fdholder-transferdumpc.
- The file descriptor transfer will occur from the s6-fdholderd daemon listening on pathfrom to the one listening on pathto.

## Options

- `-t timeoutfrom:timeoutto` : if the operations cannot be processed in timeoutfrom (for the connection to pathfrom) or timeoutto (for the connection to pathto) milliseconds, then fail with an error message. Communications with the servers should be near-instant, so this option is only here to protect users against programming errors (connecting to the wrong socket, for instance).